@@ -78,6 +78,12 @@ class Command(BaseCommand):
         'SESSION_COOKIE_SAMESITE',
         'CACHE_MIDDLEWARE_KEY_PREFIX',
         'AUTHENTICATION_BACKENDS',
+        'X_FRAME_OPTIONS',
+        'CSRF_HEADER_NAME',
+        'CSRF_TRUSTED_ORIGINS',
+        'CORS_ALLOW_METHODS',
+        'CORS_ORIGIN_ALLOW_ALL',
+        'CORS_EXPOSE_HEADERS'
     ]
     
     def add_arguments(self, parser):
@@ -221,7 +227,15 @@ class Command(BaseCommand):
             self.stdout.write(self.style.ERROR('Session settings not found in settings.py file.'))
             pass
         
-        
+        try:
+            x_frame_options = settings.X_FRAME_OPTIONS
+            csrf_header_name = settings.CSRF_HEADER_NAME
+            cors_allow_methods = settings.CORS_ALLOW_METHODS
+            cors_origin_allow_all = settings.CORS_ORIGIN_ALLOW_ALL
+            cors_expose_headers = settings.CORS_EXPOSE_HEADERS
+        except Exception as e:
+            self.stdout.write(self.style.ERROR('Security settings not found in settings.py file.'))
+            pass
         
     def create_files(self, site_domain, site_name, force=False):
         time = datetime.now().strftime('%Y%m%d%H%M%S')
@@ -430,6 +444,49 @@ class Command(BaseCommand):
                 'oauth2_provider.backends.OAuth2Backend',
                 'django.contrib.auth.backends.ModelBackend',             
             ]
+            
+        if not hasattr(settings, 'X_FRAME_OPTIONS'):
+            self.stdout.write(self.style.NOTICE('Adding X_FRAME_OPTIONS to settings.py file.'))
+            settings.X_FRAME_OPTIONS = 'SAMEORIGIN'
+        
+        if not hasattr(settings, 'CSRF_HEADER_NAME'):
+            self.stdout.write(self.style.NOTICE('Adding CSRF_HEADER_NAME to settings.py file.'))
+            settings.CSRF_HEADER_NAME = 'HTTP_X_CSRFTOKEN'
+            
+        if not hasattr(settings, 'CSRF_TRUSTED_ORIGINS'):
+            self.stdout.write(self.style.NOTICE('Adding CSRF_TRUSTED_ORIGINS to settings.py file.'))
+            settings.CSRF_TRUSTED_ORIGINS = [
+                f'http://{settings.SITE_DOMAIN}',
+                f'https://{settings.SITE_DOMAIN}',
+                f'http://localhost:3000',
+                f'https://localhost:8000',
+            ]
+        
+        if not hasattr(settings, 'CORS_ALLOW_METHODS'):
+            self.stdout.write(self.style.NOTICE('Adding CORS_ALLOW_METHODS to settings.py file.'))
+            settings.CORS_ALLOW_METHODS = ['DELETE', 'GET', 'OPTIONS', 'PATCH', 'POST', 'PUT']
+            
+        if not hasattr(settings, 'CORS_ORIGIN_ALLOW_ALL'):
+            self.stdout.write(self.style.NOTICE('Adding CORS_ORIGIN_ALLOW_ALL to settings.py file.'))
+            settings.CORS_ORIGIN_ALLOW_ALL = True
+            
+        if not hasattr(settings, 'CORS_EXPOSE_HEADERS'):
+            self.stdout.write(self.style.NOTICE('Adding CORS_EXPOSE_HEADERS to settings.py file.'))
+            settings.CORS_EXPOSE_HEADERS = ['Content-Disposition', 'Content-Type', 'Access-Control-Allow-Origin']
+        
+        if not hasattr(settings, 'CORS_ALLOW_CREDENTIALS'):
+            self.stdout.write(self.style.NOTICE('Adding CORS_ALLOW_CREDENTIALS to settings.py file.'))
+            settings.CORS_ALLOW_CREDENTIALS = True
+            
+        if not hasattr(settings, 'CORS_ORIGIN_WHITELIST'):
+            self.stdout.write(self.style.NOTICE('Adding CORS_ORIGIN_WHITELIST to settings.py file.'))
+            
+            settings.CORS_ORIGIN_WHITELIST = [
+                f'http://{settings.SITE_DOMAIN}',
+                f'https://{settings.SITE_DOMAIN}',
+                f'http://localhost:3000',
+                f'https://localhost:8000',                
+            ]
         
         # create celery.py file
         celery_py = os.path.join(base_dir, f'{project_name}/celery.py')
